// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "boost/python/object.hpp"
#include "CvGraphVtx2D.pypp.hpp"

namespace bp = boost::python;

struct CvGraphVtx2D_wrapper : CvGraphVtx2D, bp::wrapper< CvGraphVtx2D > {

    CvGraphVtx2D_wrapper(CvGraphVtx2D const & arg )
    : CvGraphVtx2D( arg )
      , bp::wrapper< CvGraphVtx2D >(){
        // copy constructor
        
    }

    CvGraphVtx2D_wrapper()
    : CvGraphVtx2D()
      , bp::wrapper< CvGraphVtx2D >(){
        // null constructor
        
    }

    static bp::object get_first( ::CvGraphVtx2D const & inst ){        
        return inst.first? bp::object(inst.first): bp::object();
    }

    static bp::object get_ptr( ::CvGraphVtx2D const & inst ){        
        return inst.ptr? bp::object(inst.ptr): bp::object();
    }

};

void register_CvGraphVtx2D_class(){

    bp::class_< CvGraphVtx2D_wrapper >( "CvGraphVtx2D" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvGraphVtx2D >() )    
        .def_readwrite( "flags", &CvGraphVtx2D::flags )    
        .add_property( "first", bp::make_function(&::CvGraphVtx2D_wrapper::get_first) )    
        .add_property( "ptr", bp::make_function(&::CvGraphVtx2D_wrapper::get_ptr) );

}
