// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvHistogram.pypp.hpp"

namespace bp = boost::python;

void register_CvHistogram_class(){

    bp::class_< CvHistogram >( "CvHistogram" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvHistogram >() )    
        .def_readwrite( "mat", &CvHistogram::mat )    
        .def_readwrite( "type", &CvHistogram::type );

}
