// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "opencv_extra.hpp"
#include "StarDetector.pypp.hpp"

namespace bp = boost::python;

static bp::sequence call1( ::cv::StarDetector const & inst, ::cv::Mat const & image ){
    std::vector< cv::KeyPoint > keypoints2;
    inst.operator()(image, keypoints2);
    return convert_vector_to_seq(keypoints2);
}

void register_StarDetector_class(){

    bp::class_< cv::StarDetector >( "StarDetector", bp::init< >() )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< cv::StarDetector >() )    
        .def( bp::init< int, int, int, int, int >(( bp::arg("_maxSize"), bp::arg("_responseThreshold"), bp::arg("_lineThresholdProjected"), bp::arg("_lineThresholdBinarized"), bp::arg("_suppressNonmaxSize") )) )    
        .def( 
            "__call__"
            , (bp::sequence (*)( ::cv::StarDetector const &,::cv::Mat const & ))( &call1 )
            , ( bp::arg("inst"), bp::arg("image") ) );

}
