// This file has been generated by Py++.

#ifndef CvHistogram_hpp__pyplusplus_wrapper
#define CvHistogram_hpp__pyplusplus_wrapper

void register_CvHistogram_class();

#endif//CvHistogram_hpp__pyplusplus_wrapper
